<?php

/**
 * @author          Tassos Marinos <info@tassos.gr>
 * @link            http://www.tassos.gr
 * @copyright       Copyright © 2017 Tassos Marinos All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
 */

// No direct access
defined('_JEXEC') or die;

require_once __DIR__ . '/wrapper.php';

/**
 *  The reCAPTCHA Wrapper
 */
class NR_ReCaptcha extends NR_Wrapper
{
	/**
	 *  Service Endpoint
	 *
	 *  @var  string
	 */
	protected $endpoint = 'https://www.google.com/recaptcha/api/siteverify';

	/**
	 * Create a new instance
	 * 
	 * @param   array $options
	 * 
	 * @throws \Exception
	 */
	public function __construct($options = array())
	{
		parent::__construct();

		// Retrieve secret key from framework's settings if not key is passed
		$secret = array_key_exists('secret', $options) ? $options['secret'] : NRFrameworkFunctions::params()->get("recaptcha_secretkey");
		
		$this->setKey($secret);
	}

	/**
	 *  Calls the reCAPTCHA siteverify API to verify whether the user passes reCAPTCHA test.
	 *
	 *  @param   string   $response  Response string from recaptcha verification.
	 *  @param   string   $remoteip  IP address of end user
	 *
	 *  @return  bool                Returns true if the user passes reCAPTCHA test
	 */
	public function validate($response, $remoteip = null)
	{
		if (empty($response) || is_null($response))
		{
			return $this->setError('Please validate');
		}

		$data = array(
			'secret'   => $this->key,
			'response' => $response,
			'remoteip' => $remoteip ?: JFactory::getApplication()->input->server->get('REMOTE_ADDR', '', 'string'),
		);

		$this->get('', $data);

		return true;
	}

	/**
	 * Check if the response was successful or a failure. If it failed, store the error.
	 *
	 * @return bool     If the request was successful
	 */
	protected function determineSuccess()
	{
		$success = parent::determineSuccess();

		$body = $this->last_response['body'];

		if ($body['success'] == false && array_key_exists('error-codes', $body) && count($body['error-codes']) > 0)
		{
			$success = $this->setError(implode(", ", $body['error-codes']));
		}

		return ($this->request_successful = $success);
	}

	private function setError($error)
	{
		$this->last_error = 'ReCaptcha: ' . $error;
		return false;
	}
}
